@@ -7,6 +7,21 @@ class Field(BaseField):
     """
     Basic field
     """
+    def __init__(self, type_class, param=None, required=False, description=None, **kwargs):
+        self._parameter = None
+
+        if isinstance(param, types.Parameter):
+            if param.type_class and type_class != param.type_class:
+                raise ValueError('Parameter type is not the same as field type.')
+
+            # keep original parameter for .parameter property
+            self._parameter = param
+            required = required or self._parameter.required
+            description = description or self._parameter.description
+            param = self._parameter.name
+
+        super(Field, self).__init__(type_class, param=param, required=required, description=description, **kwargs)
+
     def resolve(self, value):
         if not issubclass(self.type_class, types.MapObject):
             return super(Field, self).resolve(value)
@@ -19,6 +34,28 @@ class Field(BaseField):
 
         return self.type_class(parameters=value)
 
+    @property
+    def parameter(self):
+        """
+        If the field relies on parameter, returns Parameter object
+        """
+        if not self.param: return None
+
+        if self._parameter:
+            self._parameter.required = self.required
+            self._parameter.description = self.description
+
+            return self._parameter
+
+        self._parameter = types.Parameter(
+            name=self.param,
+            type_class=self.type_class,
+            required=self.required,
+            description=self.description,
+        )
+
+        return self._parameter
+
 
 class Nested(Field):
     """
@@ -125,3 +162,16 @@ class Map(Field):
             value = mapping(value) if callable(mapping) else mapping
 
         return super(Map, self).resolve(value)
+
+
+class Date(Field):
+    """
+    Resolves to string that represents a date
+    """
+    def __init__(self, format='%Y-%m-%d', **kwargs):
+        self.format = format
+        super(Date, self).__init__(types.DateStringType, **kwargs)
+
+    def resolve(self, value):
+        date_string = value.strftime(self.format)
+        return super(Date, self).resolve(date_string)
